/*
 * Copyright 2014 Sam Elsharif
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.msxlaunchers.openmsx.launcher.ui.view;

import info.msxlaunchers.openmsx.launcher.data.settings.constants.Language;

import java.util.Set;

/**
 * Interface for Database Manager UI View
 * 
 * @since v1.3
 * @author Sam Elsharif
 *
 */
public interface DatabaseManagerView
{
	/**
	 * Displays screen to manage databases
	 * 
	 * @param language Language
	 * @param rightToLeft Flag to determine screen orientation based on language
	 * @param databases Set containing databases
	 */
	void displayScreen( Language language, boolean rightToLeft, Set<String> databases );

	/**
	 * Displays screen to prompt user to rename database
	 * 
	 * @param database Name of database
	 * @param language Language
	 * @param rightToLeft Flag to determine screen orientation based on language
	 * @param databases Set containing databases
	 * @return New name of database
	 */
	String displayRenameDatabaseScreen( String database, Language language, boolean rightToLeft );
}
